@@ -453,14 +453,14 @@ def test_dask_svd_self_consistent(m, n):
         assert d_e.dtype == e.dtype
 
 
-@pytest.mark.parametrize("iterator", [("power", 1), ("QR", 1)])
+@pytest.mark.parametrize("iterator", ["power", "QR"])
 def test_svd_compressed_compute(iterator):
     x = da.ones((100, 100), chunks=(10, 10))
     u, s, v = da.linalg.svd_compressed(
-        x, k=2, iterator=iterator[0], n_power_iter=iterator[1], compute=True, seed=123
+        x, k=2, iterator=iterator, n_power_iter=1, compute=True, seed=123
     )
     uu, ss, vv = da.linalg.svd_compressed(
-        x, k=2, iterator=iterator[0], n_power_iter=iterator[1], seed=123
+        x, k=2, iterator=iterator, n_power_iter=1, seed=123
     )
 
     assert len(v.dask) < len(vv.dask)
@@ -536,20 +536,6 @@ def test_svd_compressed_shapes(m, n, k, chunks):
     assert v.shape == (r, n)
 
 
-@pytest.mark.parametrize("iterator", [("power", 1), ("QR", 1)])
-def test_svd_compressed_compute(iterator):
-    x = da.ones((100, 100), chunks=(10, 10))
-    u, s, v = da.linalg.svd_compressed(
-        x, 2, iterator=iterator[0], n_power_iter=iterator[1], compute=True, seed=123
-    )
-    uu, ss, vv = da.linalg.svd_compressed(
-        x, 2, iterator=iterator[0], n_power_iter=iterator[1], seed=123
-    )
-
-    assert len(v.dask) < len(vv.dask)
-    assert_eq(v, vv)
-
-
 def _check_lu_result(p, l, u, A):
     assert np.allclose(p.dot(l).dot(u), A)
 
@@ -774,8 +760,19 @@ def _get_symmat(size):
     return lA.dot(lA.T)
 
 
+# `sym_pos` kwarg was deprecated in scipy 1.9.0
+# ref: https://github.com/dask/dask/issues/9335
+def _scipy_linalg_solve(a, b, assume_a):
+    if parse_version(scipy.__version__) >= parse_version("1.9.0"):
+        return scipy.linalg.solve(a=a, b=b, assume_a=assume_a)
+    elif assume_a == "pos":
+        return scipy.linalg.solve(a=a, b=b, sym_pos=True)
+    else:
+        return scipy.linalg.solve(a=a, b=b)
+
+
 @pytest.mark.parametrize(("shape", "chunk"), [(20, 10), (30, 6)])
-def test_solve_sym_pos(shape, chunk):
+def test_solve_assume_a(shape, chunk):
     np.random.seed(1)
 
     A = _get_symmat(shape)
@@ -785,30 +782,39 @@ def test_solve_sym_pos(shape, chunk):
     b = np.random.randint(1, 10, shape)
     db = da.from_array(b, chunk)
 
-    res = da.linalg.solve(dA, db, sym_pos=True)
-    assert_eq(res, scipy.linalg.solve(A, b, sym_pos=True), check_graph=False)
+    res = da.linalg.solve(dA, db, assume_a="pos")
+    assert_eq(res, _scipy_linalg_solve(A, b, assume_a="pos"), check_graph=False)
     assert_eq(dA.dot(res), b.astype(float), check_graph=False)
 
     # tall-and-skinny matrix
     b = np.random.randint(1, 10, (shape, 5))
     db = da.from_array(b, (chunk, 5))
 
-    res = da.linalg.solve(dA, db, sym_pos=True)
-    assert_eq(res, scipy.linalg.solve(A, b, sym_pos=True), check_graph=False)
+    res = da.linalg.solve(dA, db, assume_a="pos")
+    assert_eq(res, _scipy_linalg_solve(A, b, assume_a="pos"), check_graph=False)
     assert_eq(dA.dot(res), b.astype(float), check_graph=False)
 
     # matrix
     b = np.random.randint(1, 10, (shape, shape))
     db = da.from_array(b, (chunk, chunk))
 
-    res = da.linalg.solve(dA, db, sym_pos=True)
-    assert_eq(res, scipy.linalg.solve(A, b, sym_pos=True), check_graph=False)
+    res = da.linalg.solve(dA, db, assume_a="pos")
+    assert_eq(res, _scipy_linalg_solve(A, b, assume_a="pos"), check_graph=False)
     assert_eq(dA.dot(res), b.astype(float), check_graph=False)
 
+    with pytest.raises(FutureWarning, match="sym_pos keyword is deprecated"):
+        res = da.linalg.solve(dA, db, sym_pos=True)
+        assert_eq(res, _scipy_linalg_solve(A, b, assume_a="pos"), check_graph=False)
+        assert_eq(dA.dot(res), b.astype(float), check_graph=False)
+
+    with pytest.raises(FutureWarning, match="sym_pos keyword is deprecated"):
+        res = da.linalg.solve(dA, db, sym_pos=False)
+        assert_eq(res, _scipy_linalg_solve(A, b, assume_a="gen"), check_graph=False)
+        assert_eq(dA.dot(res), b.astype(float), check_graph=False)
+
 
 @pytest.mark.parametrize(("shape", "chunk"), [(20, 10), (12, 3), (30, 3), (30, 6)])
 def test_cholesky(shape, chunk):
-
     A = _get_symmat(shape)
     dA = da.from_array(A, (chunk, chunk))
     assert_eq(
@@ -980,7 +986,7 @@ def test_svd_incompatible_dimensions(ndim):
         da.linalg.svd(x)
 
 
-@pytest.mark.xfail(  # Remove after NumPy 1.22 release is out
+@pytest.mark.xfail(
     sys.platform == "darwin" and _np_version < parse_version("1.22"),
     reason="https://github.com/dask/dask/issues/7189",
     strict=False,
@@ -1002,7 +1008,7 @@ def test_norm_any_ndim(shape, chunks, axis, norm, keepdims):
 
 
 @pytest.mark.slow
-@pytest.mark.xfail(  # Remove after NumPy 1.22 release is out
+@pytest.mark.xfail(
     sys.platform == "darwin" and _np_version < parse_version("1.22"),
     reason="https://github.com/dask/dask/issues/7189",
     strict=False,
