@@ -639,23 +639,38 @@ def _aggregate_stats(
         if len(file_row_group_column_stats) > 1:
             df_cols = pd.DataFrame(file_row_group_column_stats)
         for ind, name in enumerate(stat_col_indices):
-            i = ind * 2
+            i = ind * 3
             if df_cols is None:
-                s["columns"].append(
-                    {
-                        "name": name,
-                        "min": file_row_group_column_stats[0][i],
-                        "max": file_row_group_column_stats[0][i + 1],
-                    }
-                )
+                minval = file_row_group_column_stats[0][i]
+                maxval = file_row_group_column_stats[0][i + 1]
+                null_count = file_row_group_column_stats[0][i + 2]
+                if minval == maxval and null_count:
+                    # Remove "dangerous" stats (min == max, but null values exist)
+                    s["columns"].append({"null_count": null_count})
+                else:
+                    s["columns"].append(
+                        {
+                            "name": name,
+                            "min": minval,
+                            "max": maxval,
+                            "null_count": null_count,
+                        }
+                    )
             else:
-                s["columns"].append(
-                    {
-                        "name": name,
-                        "min": df_cols.iloc[:, i].min(),
-                        "max": df_cols.iloc[:, i + 1].max(),
-                    }
-                )
+                minval = df_cols.iloc[:, i].dropna().min()
+                maxval = df_cols.iloc[:, i + 1].dropna().max()
+                null_count = df_cols.iloc[:, i + 2].sum()
+                if minval == maxval and null_count:
+                    s["columns"].append({"null_count": null_count})
+                else:
+                    s["columns"].append(
+                        {
+                            "name": name,
+                            "min": minval,
+                            "max": maxval,
+                            "null_count": null_count,
+                        }
+                    )
         return s
 
 
