@@ -18,7 +18,7 @@ from dask.utils import dependency_depth, tmpdir, tmpfile
 
 # there's no support in upstream for writing HDF with extension dtypes yet.
 # see https://github.com/pandas-dev/pandas/issues/31199
-pytestmark = pytest.mark.skip_with_pyarrow_strings
+pytestmark = pytest.mark.skip_with_pyarrow_strings  # no support for hdf yet
 
 
 def test_to_hdf():
