@@ -531,19 +531,23 @@ def _maybe_sort(a, check_index: bool):
     return a.sort_index() if check_index else a
 
 
-def assert_eq_dtypes(a, b):
-    # Temporary changes to look for pyarrow dtype failures
+def _maybe_convert_string(a, b):
     import dask
 
     if dask.config.get("dataframe.convert_string"):
         from dask.dataframe._pyarrow import to_pyarrow_string
 
-        if isinstance(a, (pd.DataFrame, pd.Series)):
+        if isinstance(a, (pd.DataFrame, pd.Series, pd.Index)):
             a = to_pyarrow_string(a)
 
-        if isinstance(b, (pd.DataFrame, pd.Series)):
+        if isinstance(b, (pd.DataFrame, pd.Series, pd.Index)):
             b = to_pyarrow_string(b)
 
+    return a, b
+
+
+def assert_eq_dtypes(a, b):
+    a, b = _maybe_convert_string(a, b)
     tm.assert_series_equal(a.dtypes.value_counts(), b.dtypes.value_counts())
 
 
@@ -578,17 +582,7 @@ def assert_eq(
     if hasattr(b, "to_pandas"):
         b = b.to_pandas()
 
-    # Temporary changes to look for pyarrow dtype failures
-    import dask
-
-    if dask.config.get("dataframe.convert_string"):
-        from dask.dataframe._pyarrow import to_pyarrow_string
-
-        if isinstance(a, (pd.DataFrame, pd.Series, pd.Index)):
-            a = to_pyarrow_string(a)
-
-        if isinstance(b, (pd.DataFrame, pd.Series, pd.Index)):
-            b = to_pyarrow_string(b)
+    a, b = _maybe_convert_string(a, b)
 
     if isinstance(a, (pd.DataFrame, pd.Series)) and sort_results:
         a = _maybe_sort(a, check_index)
@@ -818,7 +812,9 @@ def meta_series_constructor(like):
 def get_string_dtype():
     """Depending on config setting, we might convert objects to pyarrow strings"""
     return (
-        pd.StringDtype("pyarrow") if config.get("dataframe.convert_string") else object
+        pd.StringDtype("pyarrow")
+        if bool(config.get("dataframe.convert_string"))
+        else object
     )
 
 
