@@ -1,9 +1,9 @@
-import importlib.metadata
 import json
 import platform
 import sys
 
 import click
+import importlib_metadata
 import pytest
 from click.testing import CliRunner
 
@@ -62,13 +62,13 @@ def good_command_2():
 def test_register_command_ep():
     from dask.cli import _register_command_ep
 
-    bad_ep = importlib.metadata.EntryPoint(
+    bad_ep = importlib_metadata.EntryPoint(
         name="bad",
         value="dask.tests.test_cli:bad_command",
         group="dask_cli",
     )
 
-    good_ep = importlib.metadata.EntryPoint(
+    good_ep = importlib_metadata.EntryPoint(
         name="good",
         value="dask.tests.test_cli:good_command",
         group="dask_cli",
@@ -90,13 +90,13 @@ def dummy_cli_2():
 def test_repeated_name_registration_warn():
     from dask.cli import _register_command_ep
 
-    one = importlib.metadata.EntryPoint(
+    one = importlib_metadata.EntryPoint(
         name="one",
         value="dask.tests.test_cli:good_command",
         group="dask_cli",
     )
 
-    two = importlib.metadata.EntryPoint(
+    two = importlib_metadata.EntryPoint(
         name="two",
         value="dask.tests.test_cli:good_command_2",
         group="dask_cli",
